@@ -12,7 +12,7 @@ from cbra.cors import DefaultPolicy
 
 CORSPolicy: type[DefaultPolicy] = DefaultPolicy.new(
     allow_credentials=True,
-    allowed_origins=settings.CORS_ALLOWED_HOSTS,
+    allowed_origins=getattr(settings, 'CORS_ALLOWED_HOSTS', []),
     allowed_headers={"Content-Type", "Cookies"},
     allowed_response_headers={"Set-Cookie"}
 )
\ No newline at end of file
