@@ -88,6 +88,16 @@ class AuthenticatedSessionPrincipal(ISessionPrincipal):
     aal: int = 1
     ial: int = 1
 
+    def get_auth_time(self) -> int:
+        return self.auth_time
+
+    def get_session_claims(self) -> dict[str, Any]:
+        return {
+            'aal': self.aal,
+            'email': self.email,
+            'email_verified': self.email_verified
+        }
+
     def get_session_id(self) -> int | None:
         return self.id
 
