@@ -26,7 +26,6 @@ class GoogleDatastoreRepository(ddd.Repository):
     client: Client
     exclude: set[str] = set()
     kind: str
-    id_attname: str = 'id'
     model: type[BaseModel]
     id_attr: str
 
@@ -86,11 +85,16 @@ class GoogleDatastoreRepository(ddd.Repository):
             self.storage_key(entity_id)
         )
 
-    async def get_entity_by_id(self, entity_id: int, kind: str | None = None) -> Entity | None:
+    async def get_entity_by_id(
+        self,
+        entity_id: int,
+        kind: str | None = None,
+        parent: Key | None = None
+    ) -> Entity | None:
         return await self.run_in_executor(
             functools.partial(
                 self.client.get, # type: ignore
-                key=self.client.key(kind or self.kind, entity_id) # type: ignore
+                key=self.client.key(kind or self.kind, entity_id, parent=parent) # type: ignore
             )
         )
 
